@@ -2,4 +2,4 @@ from .detections import Detections
 from .box_detection import BoxDetection
 from .point_detection import PointDetection
 from .segmentation_detection import SegmentationDetection, Shape, Point
-from .outbox import Outbox
+from .outbox.outbox import Outbox
